==> DGN1000_VA1.00.50_mw_WW_src.tar.7z: DGN1000_VA1.00.50_mw_WW_src/apps/busybox-1.13.1/include/applet_tables.h <==
/* This is a generated file, don't edit */

#define NUM_APPLETS 65

const char applet_names[] ALIGN1 = ""
"[" "\0"
"[[" "\0"
"arp" "\0"
"arping" "\0"
"ash" "\0"
"brctl" "\0"
"cat" "\0"
"chmod" "\0"
"chpasswd" "\0"
"cp" "\0"
"cut" "\0"
"date" "\0"
"df" "\0"
"dmesg" "\0"
"echo" "\0"
"egrep" "\0"
"ether-wake" "\0"
"false" "\0"
"fgrep" "\0"
"free" "\0"
"ftpget" "\0"
"ftpput" "\0"
"grep" "\0"
"halt" "\0"
"hostname" "\0"
"ifconfig" "\0"
"init" "\0"
"insmod" "\0"
"kill" "\0"
"killall" "\0"
"less" "\0"
"ln" "\0"
"login" "\0"
"ls" "\0"
"lsmod" "\0"
"md5sum" "\0"
"mkdir" "\0"
"mknod" "\0"
"more" "\0"
"mount" "\0"
"mv" "\0"
"nc" "\0"
"netstat" "\0"
"passwd" "\0"
"ping" "\0"
"ping6" "\0"
"poweroff" "\0"
"ps" "\0"
"reboot" "\0"
"rm" "\0"
"rmmod" "\0"
"route" "\0"
"sed" "\0"
"sh" "\0"
"sleep" "\0"
"telnet" "\0"
"telnetd" "\0"
"test" "\0"
"top" "\0"
"traceroute" "\0"
"true" "\0"
"umount" "\0"
"uptime" "\0"
"vi" "\0"
"wget" "\0"
;

int (*const applet_main[])(int argc, char **argv) = {
test_main,
test_main,
arp_main,
arping_main,
ash_main,
brctl_main,
cat_main,
chmod_main,
chpasswd_main,
cp_main,
cut_main,
date_main,
df_main,
dmesg_main,
echo_main,
grep_main,
ether_wake_main,
false_main,
grep_main,
free_main,
ftpgetput_main,
ftpgetput_main,
grep_main,
halt_main,
hostname_main,
ifconfig_main,
init_main,
insmod_main,
kill_main,
kill_main,
less_main,
ln_main,
login_main,
ls_main,
lsmod_main,
md5_sha1_sum_main,
mkdir_main,
mknod_main,
more_main,
mount_main,
mv_main,
nc_main,
netstat_main,
passwd_main,
ping_main,
ping6_main,
halt_main,
ps_main,
halt_main,
rm_main,
rmmod_main,
route_main,
sed_main,
ash_main,
sleep_main,
telnet_main,
telnetd_main,
test_main,
top_main,
traceroute_main,
true_main,
umount_main,
uptime_main,
vi_main,
wget_main,
};
const uint16_t applet_nameofs[] ALIGN2 = {
0x0000,
0x0002,
0x0005,
0x0009,
0x0010,
0x0014,
0x001a,
0x001e,
0x0024,
0x002d,
0x0030,
0x0034,
0x0039,
0x003c,
0x0042,
0x0047,
0x004d,
0x0058,
0x005e,
0x0064,
0x0069,
0x0070,
0x0077,
0x007c,
0x0081,
0x008a,
0x0093,
0x0098,
0x009f,
0x00a4,
0x00ac,
0x00b1,
0x80b4,
0x00ba,
0x00bd,
0x00c3,
0x00ca,
0x00d0,
0x00d6,
0x00db,
0x00e1,
0x00e4,
0x00e7,
0x80ef,
0x40f6,
0x00fb,
0x0101,
0x010a,
0x010d,
0x0114,
0x0117,
0x011d,
0x0123,
0x0127,
0x012a,
0x0130,
0x0137,
0x013f,
0x0144,
0x4148,
0x0153,
0x0158,
0x015f,
0x0166,
0x0169,
};
#define MAX_APPLET_NAME_LEN 10

==> DGN1000_VA1.00.51_mw_WW_src.tar.7z: DGN1000_VA1.00.51_mw_WW_src/apps/busybox-1.13.1/include/applet_tables.h <==
/* This is a generated file, don't edit */

#define NUM_APPLETS 92

const char applet_names[] ALIGN1 = ""
"[" "\0"
"[[" "\0"
"arp" "\0"
"arping" "\0"
"ash" "\0"
"basename" "\0"
"brctl" "\0"
"cat" "\0"
"chmod" "\0"
"chpasswd" "\0"
"chroot" "\0"
"clear" "\0"
"cp" "\0"
"cut" "\0"
"date" "\0"
"df" "\0"
"dirname" "\0"
"dmesg" "\0"
"echo" "\0"
"egrep" "\0"
"ether-wake" "\0"
"false" "\0"
"fgrep" "\0"
"find" "\0"
"free" "\0"
"ftpget" "\0"
"ftpput" "\0"
"grep" "\0"
"halt" "\0"
"head" "\0"
"hostname" "\0"
"ifconfig" "\0"
"init" "\0"
"insmod" "\0"
"ipcalc" "\0"
"kill" "\0"
"killall" "\0"
"less" "\0"
"ln" "\0"
"login" "\0"
"ls" "\0"
"lsmod" "\0"
"md5sum" "\0"
"mkdir" "\0"
"mkfifo" "\0"
"mknod" "\0"
"more" "\0"
"mount" "\0"
"mv" "\0"
"nc" "\0"
"netstat" "\0"
"nice" "\0"
"nohup" "\0"
"nslookup" "\0"
"passwd" "\0"
"pidof" "\0"
"ping" "\0"
"ping6" "\0"
"poweroff" "\0"
"ps" "\0"
"realpath" "\0"
"reboot" "\0"
"renice" "\0"
"rm" "\0"
"rmdir" "\0"
"rmmod" "\0"
"route" "\0"
"sed" "\0"
"sh" "\0"
"sleep" "\0"
"sort" "\0"
"swapoff" "\0"
"swapon" "\0"
"tail" "\0"
"tee" "\0"
"telnet" "\0"
"telnetd" "\0"
"test" "\0"
"top" "\0"
"touch" "\0"
"traceroute" "\0"
"true" "\0"
"umount" "\0"
"uptime" "\0"
"usleep" "\0"
"vi" "\0"
"watch" "\0"
"wc" "\0"
"wget" "\0"
"which" "\0"
"who" "\0"
"yes" "\0"
;

int (*const applet_main[])(int argc, char **argv) = {
test_main,
test_main,
arp_main,
arping_main,
ash_main,
basename_main,
brctl_main,
cat_main,
chmod_main,
chpasswd_main,
chroot_main,
clear_main,
cp_main,
cut_main,
date_main,
df_main,
dirname_main,
dmesg_main,
echo_main,
grep_main,
ether_wake_main,
false_main,
grep_main,
find_main,
free_main,
ftpgetput_main,
ftpgetput_main,
grep_main,
halt_main,
head_main,
hostname_main,
ifconfig_main,
init_main,
insmod_main,
ipcalc_main,
kill_main,
kill_main,
less_main,
ln_main,
login_main,
ls_main,
lsmod_main,
md5_sha1_sum_main,
mkdir_main,
mkfifo_main,
mknod_main,
more_main,
mount_main,
mv_main,
nc_main,
netstat_main,
nice_main,
nohup_main,
nslookup_main,
passwd_main,
pidof_main,
ping_main,
ping6_main,
halt_main,
ps_main,
realpath_main,
halt_main,
renice_main,
rm_main,
rmdir_main,
rmmod_main,
route_main,
sed_main,
ash_main,
sleep_main,
sort_main,
swap_on_off_main,
swap_on_off_main,
tail_main,
tee_main,
telnet_main,
telnetd_main,
test_main,
top_main,
touch_main,
traceroute_main,
true_main,
umount_main,
uptime_main,
usleep_main,
vi_main,
watch_main,
wc_main,
wget_main,
which_main,
who_main,
yes_main,
};
const uint16_t applet_nameofs[] ALIGN2 = {
0x0000,
0x0002,
0x0005,
0x0009,
0x0010,
0x0014,
0x001d,
0x0023,
0x0027,
0x002d,
0x0036,
0x003d,
0x0043,
0x0046,
0x004a,
0x004f,
0x0052,
0x005a,
0x0060,
0x0065,
0x006b,
0x0076,
0x007c,
0x0082,
0x0087,
0x008c,
0x0093,
0x009a,
0x009f,
0x00a4,
0x00a9,
0x00b2,
0x00bb,
0x00c0,
0x00c7,
0x00ce,
0x00d3,
0x00db,
0x00e0,
0x80e3,
0x00e9,
0x00ec,
0x00f2,
0x00f9,
0x00ff,
0x0106,
0x010c,
0x0111,
0x0117,
0x011a,
0x011d,
0x0125,
0x012a,
0x0130,
0x8139,
0x0140,
0x4146,
0x014b,
0x0151,
0x015a,
0x015d,
0x0166,
0x016d,
0x0174,
0x0177,
0x017d,
0x0183,
0x0189,
0x018d,
0x0190,
0x0196,
0x019b,
0x01a3,
0x01aa,
0x01af,
0x01b3,
0x01ba,
0x01c2,
0x01c7,
0x01cb,
0x41d1,
0x01dc,
0x01e1,
0x01e8,
0x01ef,
0x01f6,
0x01f9,
0x01ff,
0x0202,
0x0207,
0x020d,
0x0211,
};
#define MAX_APPLET_NAME_LEN 10
